@@ -56,6 +56,9 @@ class Observable(ObservableBase):
         # [v['func'](self._value) for v in self.changeActionsList]
         self.trigger()
 
+    def setValue(self, v):
+        self.value = v
+
 class Computed(ObservableBase):
     def __init__(self, obs, func):
         super().__init__()
