@@ -1,5 +1,6 @@
 from PyQt5.QtGui import QImage, QPixmap
 from PyQt5.QtWidgets import QFrame, QTabWidget
+from PyQt5.QtCore import Qt
 
 def toList(t):
     def f(s):
@@ -55,6 +56,21 @@ def frameShadow(shadow: str):
         shadow = 'plain'
     return d[shadow]
 
+def alignment(pos):
+    pos = pos.lower()
+    d = {
+        'center': Qt.AlignCenter,
+        'hcenter': Qt.AlignHCenter,
+        'vcenter': Qt.AlignVCenter,
+        'bottom': Qt.AlignBottom,
+        'top': Qt.AlignTop,
+        'right': Qt.AlignRight,
+        'left': Qt.AlignLeft
+    }
+    if pos not in d.keys():
+        pos = 'none'
+    return d[pos]
+
 def tabPosition(pos: str):
     pos = pos.lower()
     d = {
@@ -93,6 +109,10 @@ common = {
     'enable': ['setEnabled', bool]
 }
 
+align = {
+    'align': ['setAlignment', alignment]
+}
+
 btn = {
     'checked': ['setChecked', [int, bool]]
 }
@@ -134,7 +154,7 @@ ElementAttr = {
         **common, **btn
     },
     'label': {
-        **size, **common,
+        **size, **common, **align,
         'cv': ['setTextOrPixmap', cvImg],
         'cvPath': ['setPixmap', [str, cvPathImg]],
         'scaledContents': ['setScaledContents', [int, bool]]
@@ -145,6 +165,9 @@ ElementAttr = {
     },
     'status': {
         'msg': ['showMessage', str]
+    },
+    'select': {
+        'index': ['setCurrentIndex', int]
     }
 }
 
